@@ -250,13 +250,13 @@ sub version
 
 
 
-=head2 on
+=head2 set_on
 
 Set this light to be "on".
 
 =cut
 
-sub on
+sub set_on
 {
     my ($self) = (@_);
 
@@ -283,13 +283,13 @@ sub on
 }
 
 
-=head2 on
+=head2 set_off
 
 Set this light to be "off".
 
 =cut
 
-sub off
+sub set_off
 {
     my ($self) = (@_);
 
@@ -361,9 +361,9 @@ sub set_brightness
 }
 
 
-=head2 rgb
+=head2 set_rgbw
 
-Set the specified RGB values of this light.
+Set the specified RGBW values of this light.
 
 =cut
 
